function [tout,ycosbb,ysinbb] = genbbnew(cossym,sinsym,M,ts,tr)

%function [tout,ycosbb,ysinbb] = genbbnew(cossym,sinsym,M,ts,tr)
%
%Generates a 100 percent cosine baseband signals from symbol sequences, cossym and sinsym,
%with time resolution tr and symbol period ts.
%
%Input parameters
%
%cossym        the symbol sequence to be modulated on the cosine carrier
%sinsym        the symbol sequence to be modulated on the sine carrier
%M             the number of symbol levels
%ts            the symbol period
%tr            the time resolution of the signal
%
%The function returns:
%
%tout     the time vector for the waveform
%ycosbb   the base-band waveform to modulate the cosine carrier
%ysinbb   the base-band waveform to modulate the sine carrier


B=length(cossym);

%Generates a 100 percent raised cosine function for the symbol period ts over -4ts to 4ts
t=-ts*B:tr:ts*B;
ys=sin(pi*t/ts)./(pi*t/ts);
yc=cos(pi*t/ts)./(1-((2*t/ts).^2));
y=ys.*yc;


%Infinity correction
A=length(t)-1;
C=(A/2)+(0.5*ts/tr);
y(C+1)=0.5;
C=(A/2)-(0.5*ts/tr);
y(C+1)=0.5;



cossymimp=zeros(1,A+1);
sinsymimp=zeros(1,A+1);

j=1;
for i=A/2:(ts/tr):A-1
cossymimp(i)=cossym(j);
sinsymimp(i)=sinsym(j);
j=j+1;
end

%Generate baseband cosine and sine symbols by repeated convolution of 100 percent raised
%cosine pulses around weighted impulses at each symbol

ycos=conv(y,cossymimp);
ysin=conv(y,sinsymimp);

%Truncate time and waveform arrays from time 0 to one time one symbol period longer than the symbol 
%data due to the extension of the time vector under convolution

timestep=ts/tr;

arrayzerotime=(B*2-1);
arraymaxtime=(3*B);

tout=0:tr:(B+1)*ts-tr;

ycosbb=ycos(timestep*arrayzerotime:timestep*arraymaxtime-1);
ysinbb=ysin(timestep*arrayzerotime:timestep*arraymaxtime-1);

clg
subplot(211)

axis([0,(B+1)*ts-tr,-(M-1)-.2,(M-1)+.2]);

plot(tout,ycosbb,'k')
hold on

%Plot target position of cosine waveform points
for i=1:1:B
	plot(i*ts,cossym(i),'o')
end

grid


plot(tout,ysinbb,'m')

%Plot target position of sine waveform points
for i=1:1:B
	plot(i*ts,sinsym(i),'o')
end

title('Blue - cosine baseband signal; Green - sine baseband signal')

xlabel('time in seconds')

hold off